/**
 * @file
 * Contains definition of the behaviour Bootstrap settings.
 */

(function ($, Drupal, drupalSettings, once) {
  "use strict";

  Drupal.behaviors.bootstrapSettings = {
    attach: function (context, settings) {
      // The drupalSetSummary method required for this behavior is not available
      // on the Bootstrap settings page, so we need to make sure this
      // behavior is processed only if drupalSetSummary is defined.
      if (typeof $.fn.drupalSetSummary === 'undefined') {
        return;
      }

      $(once('bootstrap-theme-groups', '[data-drupal-selector="edit-theme-groups"]'),
      ).drupalSetSummary((context) => {
        const $themes = $(context).find(
          'select[name="themes\[\]"]',
        );
        if (!$themes.length || !$themes[0].value) {
          return Drupal.t('Not restricted');
        }
        console.log($themes.val());

        return Drupal.t('Restricted to !theme', { '!theme': $themes.val() });
      });

      $(once('bootstrap-request-path', '[data-drupal-selector="edit-request-path"]'),
      ).drupalSetSummary((context) => {
        const $pages = $(context).find(
          'textarea[name="pages"]',
        );
        if (!$pages.length || !$pages[0].value) {
          return Drupal.t('Not restricted');
        }

        return Drupal.t('Restricted to certain pages');
      });

    }
  };

})(jQuery, Drupal, drupalSettings, once);
